All Classes and Interfaces
Class
Description
An abstract LdapConnection class gathering the common behavior of LdapConnection
concrete classes.
A base, abstract, implementation of
PasswordPolicyResponder.An abstract class implementing the PoolableObjectFactory, for LdapConnections.
Holds the data required to complete the SASL operation
A Future to manage AddRequests.
A Future to manage BindRequests.
A Future to manage CompareRequest.
A callback for running code against a managed
LdapConnection.A listener class intended for notifying the classes using LdapNetworkConnection
in the event of any network failure
The default implementation of LdapConnectionFactory.
An implementation of
LdapConnectionValidator that checks to see that
the connection isConnected() and isAuthenticated().A factory for creating LdapConnection objects managed by LdapConnectionPool.
A schema loader which uses LdapConnection to load schema from a ApacheDS serveur
A Future to manage DeleteRequests.
An implementation of Cursor based on the underlying SearchFuture instance.
A callback for processing entries from a search result.
A Future to manage ExtendedRequests.
A builder for constructing well formed search filters according to
RFC 4515.
A Future to manage StartTLS handshake
A InvalidConnectionException is thrown if one tries to apply an operation
on a closed connection
The JAAS Login Configuration File for Kerberos
Root interface for all asynchronous LDAP connections.
Implement the X509TrustManager interface which will be used during JSSE truststore manager initialisation for LDAP
client-to-server communications over TLS/SSL.
The root interface for all the LDAP connection implementations.
A class to hold the configuration for creating an LdapConnection.
A factory that creates
LdapConnection objects using the provided
LdapConnectionConfig.Specifies the set of operations available on
LdapConnectionTemplate.A pool implementation for LdapConnection objects.
A facade for LDAP operations that handles all of the boiler plate code for
you allowing more concise operations through the use of callbacks.
A LdapConnectionTimeOutException is thrown if there is an connection time-out
situation.
An LdapConnection validator intended to be used by a GenericObjectPool to
determine whether or not a conneciton is still usable.
Provides a base implementation of a
Wrapper for LdapConnection
objects.This class is the base for every operations sent or received to and
from a LDAP server.
An RuntimeException wrapper class that allows the user to choose to have
unsuccessful responses thrown as exceptions rather than checking the
response itself for process flow.
An RuntimeException wrapper class for exceptions which add LDAP specific
information to Exceptions.
Anonymize the content of a LDIF file.
An implementation of
LdapConnectionValidator that attempts a simple
lookup on the rootDSE.The filter buildee for MatchingRuleAssertion
A buffer for storing sensitive information like passwords.
A factory for creating
objects.
invalid reference
org.apache.directory.api.ldap.model
A Future to manage ModifyDnRequest
A Future to manage ModifyRequest.
A class used to monitor the use of a LdapConnection
A Future implementation used in LdapConnection operations.
Thrown when an attempt to bind or modify a userPassword fails when using
LdapConnectionTemplate.
An callback for processing requests whose success/failure imply some sort
of password policy information.
A class for translating the outcome of a
PasswordPolicyOperation.A container for password warning information.
A wrapper around an LdapConnection that returns the connection to the pool when closed.
Edits a supplied request adding specifics.
A Future implementation used in LdapConnection operations.
The CallbackHandler implementation used by the LdapConnection during SASL mechanism based bind operations.
Holds the data required to complete the CRAM-MD5 SASL operation
Holds the data required to complete the DIGEST-MD5 SASL operation
Holds the data required to complete the EXTERNAL SASL operation
Holds the data required to complete the GSS-API SASL operation
Holds the data required to complete the SASL PLAIN operation
Holds the data required to complete the SASL operation
An implementation of Cursor based on the underlying SearchFuture instance.
A Future to manage SerachRequest.
A Future implementation used in LdapConnection operations for operations
that only get one single response.
A factory for creating LdapConnection objects managed by LdapConnectionPool.
An interface for defining wrapper objects.